==> nextcloud-13.0.1.tgz: nextcloud/apps/systemtags/l10n/es.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag…" : "Seleccionar etiqueta...",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Seleccionar etiquetas por las que filtrar",
    "No tags found" : "No se encontraron etiquetas",
    "Please select tags to filter by" : "Por favor, seleccione las etiquetas por las que desea filtrar",
    "No files found for the selected tags" : "No se han encontrado archivos para las etiquetas seleccionadas",
    "Added system tag %1$s" : "Se añadió la etiqueta delsistema %1$s",
    "Added system tag {systemtag}" : "Se añadió la etiqueta de sistema {systemtag}",
    "%1$s added system tag %2$s" : "%1$s añadió la etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} añadió la etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminada etiqueta de sistema %1$s",
    "Removed system tag {systemtag}" : "Eliminada etiqueta de sistema {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted eliminó la etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted eliminó la etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Usted añadió la etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted añadió la etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta de sistema {systemtag} a {file}",
    "You removed system tag %2$s from %1$s" : "Ha removido la etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Ha removido la etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removió la etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removió la etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Se han modificado las <strong>etiquetas de sistema</strong> de un archivo",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Create and edit collaborative tags. These tags affect all users." : "Crea y edita etiquetas colaborativas. Estas etiquetas afectan a todos los usuarios.",
    "Select tag …" : "Selecciona etiqueta...",
    "Name" : "Nombre",
    "Delete" : "Borrar",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Reset" : "Restablecer",
    "No files in here" : "Aquí no hay archivos",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/systemtags/l10n/es.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag…" : "Seleccionar etiqueta...",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Seleccionar etiquetas por las que filtrar",
    "No tags found" : "No se encontraron etiquetas",
    "Please select tags to filter by" : "Por favor, seleccione las etiquetas por las que desea filtrar",
    "No files found for the selected tags" : "No se han encontrado archivos para las etiquetas seleccionadas",
    "Added system tag %1$s" : "Se añadió la etiqueta delsistema %1$s",
    "Added system tag {systemtag}" : "Se añadió la etiqueta de sistema {systemtag}",
    "%1$s added system tag %2$s" : "%1$s añadió la etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} añadió la etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminada etiqueta de sistema %1$s",
    "Removed system tag {systemtag}" : "Eliminada etiqueta de sistema {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted eliminó la etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted eliminó la etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Usted añadió la etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted añadió la etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta de sistema {systemtag} a {file}",
    "You removed system tag %2$s from %1$s" : "Ha removido la etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Ha removido la etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removió la etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removió la etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Se han modificado las <strong>etiquetas de sistema</strong> de un archivo",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios. Adecuado para equipos.\n\n(Si eres un proveedor con una instalación en multitenencia), se aconseja desactivar esta app pues las etiquetas se comparten).",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden ser asignadas por ellos. Las etiquetas invisibles son para uso interno, pues los usuarios no pueden verlas ni asignarlas.",
    "Select tag …" : "Selecciona etiqueta...",
    "Create a new tag" : "Crear una etiqueta nueva",
    "Name" : "Nombre",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Borrar",
    "Reset" : "Restablecer",
    "No files in here" : "Aquí no hay archivos",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Create and edit collaborative tags. These tags affect all users." : "Crea y edita etiquetas colaborativas. Estas etiquetas afectan a todos los usuarios."
},
"nplurals=2; plural=(n != 1);");
